MOLAR_MASS enum
Values
- gramsPerMole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.grams, AMOUNT_OF_SUBSTANCE.moles) - gramsPerMillimole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.grams, AMOUNT_OF_SUBSTANCE.millimoles) - gramsPerMicromole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.grams, AMOUNT_OF_SUBSTANCE.micromoles) - gramsPerNanomole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.grams, AMOUNT_OF_SUBSTANCE.nanomoles) - gramsPerPicomole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.grams, AMOUNT_OF_SUBSTANCE.picomoles) - gramsPerFemtomole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.grams, AMOUNT_OF_SUBSTANCE.femtomoles) - milligramsPerMole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.milligrams, AMOUNT_OF_SUBSTANCE.moles) - milligramsPerMillimole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.milligrams, AMOUNT_OF_SUBSTANCE.millimoles) - milligramsPerMicromole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.milligrams, AMOUNT_OF_SUBSTANCE.micromoles) - milligramsPerNanomole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.milligrams, AMOUNT_OF_SUBSTANCE.nanomoles) - milligramsPerPicomole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.milligrams, AMOUNT_OF_SUBSTANCE.picomoles) - milligramsPerFemtomole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.milligrams, AMOUNT_OF_SUBSTANCE.femtomoles) - kilogramsPerMole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.kilograms, AMOUNT_OF_SUBSTANCE.moles) - kilogramsPerMillimole → const MOLAR_MASS
-
const MOLAR_MASS(MASS.kilograms, AMOUNT_OF_SUBSTANCE.millimoles)
Properties
- denominator → AMOUNT_OF_SUBSTANCE
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - numerator → MASS
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MOLAR_MASS> - A constant List of the values in this enum, in order of their declaration.