Volume class

Inheritance

Constructors

Volume({int significantFigures = 10, bool removeTrailingZeros = true, bool useScientificNotation = true, dynamic name})
Class for volume conversions, e.g. if you want to convert 1 liter in US Gallons:

Properties

australianTablespoons → Unit
no setter
centiliter → Unit
no setter
conversionTree ↔ ConversionNode<VOLUME>
Defines the relation between the units of measurement of this property. E.g. in the following example we defined: KiloDash = 1000 * Dash, DashPlus1 = Dash + 1 and OneOver(DashPlus1) = 1 / (DashPlus1):
getter/setter pairinherited
cubicCentimeters → Unit
no setter
cubicFeet → Unit
no setter
cubicInches → Unit
no setter
cubicMeters → Unit
no setter
cubicMillimeters → Unit
no setter
cubicYard → Unit
no setter
cups → Unit
no setter
deciliter → Unit
no setter
femtoliter → Unit
no setter
hashCode → int
The hash code for this object.
no setterinherited
imperialCup → Unit
no setter
imperialFluidOunces → Unit
no setter
imperialGallons → Unit
no setter
imperialGill → Unit
no setter
imperialPints → Unit
no setter
imperialQuarts → Unit
no setter
liters → Unit
no setter
mapSymbols ↔ Map<VOLUME, String>?
Map between units and its symbol
getter/setter pairinherited
metricCup → Unit
no setter
microliter → Unit
no setter
milliliters → Unit
no setter
name ↔ dynamic
The name of the Property. If it is not a custom Property is one of the values of PROPERTY.
getter/setter pairinherited
nanoliter → Unit
no setter
picoliter → Unit
no setter
removeTrailingZeros ↔ bool
Whether to remove the trailing zeros or not. E.g 1.00000000 has 9 significant figures and has trailing zeros. 1 has not trailing zeros.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
significantFigures ↔ int
The number of significant figures to keep. E.g. 1.23456789) has 9 significant figures
getter/setter pairinherited
size ↔ int
The size of the Property, i.e. the number of the Units that belong to that Property.
getter/setter pairinherited
tablespoonsUs → Unit
no setter
teaspoonsMetric → Unit
no setter
teaspoonsUs → Unit
no setter
usBarrel → Unit
no setter
useScientificNotation ↔ bool
Whether to use the scientific notation (true) for stringValues or decimal notation (false)
getter/setter pairinherited
usFluidOunces → Unit
no setter
usGallons → Unit
no setter
usGill → Unit
no setter
usPints → Unit
no setter
usQuarts → Unit
no setter

Methods

convert(VOLUME name, double? value) → void
Converts a unit with a specific name (e.g. ANGLE.degree) and value to all other units
inherited
getAll() → List<Unit>
Returns all the units converted with prefixes
inherited
getUnit(VOLUME name) → Unit
Returns the Unit with the corresponding name
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited