Unit class
Constructors
-
Unit(dynamic name, {double? value, String? symbol, String stringValueCallback(double)?})
-
The class that defines a unit of measurement object.
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
↔ dynamic
-
The name of the unit (e.g. LENGTH.meters, VOLUME.liters).
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
stringValue
↔ String?
-
getter/setter pair
-
stringValueCallback
↔ String Function(double)
-
getter/setter pair
-
symbol
↔ String?
-
The symbols that represent the unit (e.g. "m" stands for meters, "l"
stands for liter).
getter/setter pair
-
value
↔ double?
-
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited